PolygonShape class

PolygonShape is a class that represents a polygon shape.

Inheritance

Constructors

PolygonShape({BorderSide side = BorderSide.none, double sides = 5, double pointRounding = 0, double rotation = 0, double squash = 0})
PolygonShape constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → Path Function(Size parentSize)
path is a function that takes a Size and returns a Path
finalinherited
pointRounding → double
pointRounding is the point rounding of the polygon.
final
rotation → double
rotation is the rotation of the polygon.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → BorderSide
side is the side of the polygon.
final
sides → double
sides is the number of sides of the polygon.
final
squash → double
squash is the squash of the polygon.
final

Methods

build(Size parentSize, {Size? size, Matrix4? transform, AlignmentGeometry? origin = Alignment.center, AlignmentGeometry alignment = Alignment.center, Offset? offset, Offset? translate, double? margin}) → Path
inherited
invert() → Shaper
invert is a function that returns a new Shaper that invert the shape.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited